<!-- These are examples of badges you might want to add to your README:
     please update the URLs accordingly

[![Built Status](https://api.cirrus-ci.com/github/<USER>/mausam.svg?branch=main)](https://cirrus-ci.com/github/<USER>/mausam)
[![ReadTheDocs](https://readthedocs.org/projects/mausam/badge/?version=latest)](https://mausam.readthedocs.io/en/stable/)
[![Coveralls](https://img.shields.io/coveralls/github/<USER>/mausam/main.svg)](https://coveralls.io/r/<USER>/mausam)
[![PyPI-Server](https://img.shields.io/pypi/v/mausam.svg)](https://pypi.org/project/mausam/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/mausam.svg)](https://anaconda.org/conda-forge/mausam)
[![Monthly Downloads](https://pepy.tech/badge/mausam/month)](https://pepy.tech/project/mausam)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter)](https://twitter.com/mausam)
-->

[![PyPI](https://img.shields.io/pypi/v/mausam.svg)](https://pypi.org/project/mausam/)
[![Docs](https://readthedocs.org/projects/mausam/badge/?version=latest)](https://mausam.readthedocs.io/en/stable/)
![Tests](https://github.com/m-anish/mausam/actions/workflows/ci.yml/badge.svg)
[![Project generated with PyScaffold](https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold)](https://pyscaffold.org/)

# mausam

> An application to upload weather data to IoT dashboards

A longer description of your project goes here...


<!-- pyscaffold-notes -->

## Note

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
